# Changelog

Changelog for `aboto3`.
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

<!-- 
## [Unreleased] - YYYY-MM-DD

### Added

### Changed

### Deprecated

### Removed

### Fixed

### Security 
-->


## [0.1.1] - 2024-01-28

### Added

Tests for python 3.12

### Changed

Updated README to reflect recommendations.

### Removed

Support for python 3.7


## [0.1.0] - 2023-06-22

Initial Release.

